# Sample McCole Project

First paragraph

<p id="terms"></p>

-   [link text][link_key]
-   [bibliography entry](b:bibref)
-   [glossary entry](g:glossref) and [another glossary entry](g:another)
-   [](#f:figure)
-   [](#t:table)
-   [unresolved link][unresolved_link]

<figure id="f:figure">
  <figcaption>figure caption</figcaption>
</figure>

<div id="t:table" data-caption="table caption" markdown="1">
| left | right |
| :--- | ----: |
| name |   123 |
</div>

```python
name = "python"
```

```bash
shell command
```

## Lessons

<div id="lessons" markdown="1">

1.  [Introduction](@/intro/)
1.  [Conclusion](@/finale/)

</div>

##  Appendices

<div id="appendices" markdown="1">

1.  [License](@/license/)
1.  [Code of Conduct](@/conduct/)
1.  [Contributing](@/contributing/)
1.  [Bibliography](@/bibliography/)
1.  [Glossary](@/glossary/)

</div>

## Acknowledgments {: #acknowledgments}

-   *[Greg Wilson][wilson-greg]* is a programmer, author, and educator based in Toronto, Canada.

[wilson-greg]: https://third-bit.com/
